==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/kinesisanalyticsv2/kotlin/outputs/ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormat.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesisanalyticsv2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property mappingParameters Provides additional mapping information specific to the record format (such as JSON, CSV, or record fields delimited by some delimiter) on the streaming source.
 * @property recordFormatType The type of record format. Valid values: `CSV`, `JSON`.
 */
public data class
ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormat(
    public val mappingParameters:
    ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormatMappingParameters,
    public val recordFormatType: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.kinesisanalyticsv2.outputs.ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormat):
            ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormat =
            ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormat(
                mappingParameters = javaType.mappingParameters().let({ args0 ->
                    com.pulumi.aws.kinesisanalyticsv2.kotlin.outputs.ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormatMappingParameters.Companion.toKotlin(args0)
                }),
                recordFormatType = javaType.recordFormatType(),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/kinesisanalyticsv2/kotlin/outputs/ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormat.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesisanalyticsv2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property mappingParameters Provides additional mapping information specific to the record format (such as JSON, CSV, or record fields delimited by some delimiter) on the streaming source.
 * @property recordFormatType The type of record format. Valid values: `CSV`, `JSON`.
 */
public data class
ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormat(
    public val mappingParameters: ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormatMappingParameters,
    public val recordFormatType: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.kinesisanalyticsv2.outputs.ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormat): ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormat =
            ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormat(
                mappingParameters = javaType.mappingParameters().let({ args0 ->
                    com.pulumi.aws.kinesisanalyticsv2.kotlin.outputs.ApplicationApplicationConfigurationSqlApplicationConfigurationInputInputSchemaRecordFormatMappingParameters.Companion.toKotlin(args0)
                }),
                recordFormatType = javaType.recordFormatType(),
            )
    }
}
